@@ -230,7 +230,6 @@ sub create_type_map {
 		
 		blob => 'varchar',
 		mediumblob => 'varchar',
-		mediumtext => 'varchar',
 		tinyblob => 'varchar',
 		varbinary => 'varchar',
 		
@@ -312,7 +311,7 @@ sub new_int {
 sub new_float {
 	return sub {
 		m/\GNULL/gc and return undef;
-		m/\G(-?[\d]+(?:\.[\d]+(e-?[\d]+)?)?)/gc or die "expected float"; return $1;
+		m/\G(-?[\d]+\.[\d]+(e-?[\d]+)?)/gc or die "expected float"; return $1;
 	}
 }
 
@@ -372,10 +371,10 @@ MediaWiki::DumpFile::SQL - Process SQL dump files from a MediaWiki instance
   @schema = $sql->schema;
   $name = $sql->table_name;
   
-  while(defined($row = $sql->next)) {
+  while(defined($row = $sql->next) {
   	#do something with the data from the row
   }
-
+  
 =head1 FUNCTIONS
 
 =head2 new
@@ -383,8 +382,6 @@ MediaWiki::DumpFile::SQL - Process SQL dump files from a MediaWiki instance
 This is the constructor for this package. It is called with a single parameter: the location of
 a MediaWiki SQL dump file or a reference to an already open file handle. 
 
-Only the definition and data for the B<first> table in a SQL dump file is processed.
-
 =head2 next
 
 Returns a hash reference where the key is the column name from the table and the value of the hash is
